```@meta
CurrentModule = Antique
```

# Infinite Potential Well (Particle in a Box)

The infinite potential well (particle in a box) is the simplest model for quantum mechanical system.

## Definitions

This model is described with the time-independent Schrödinger equation
```math
  \hat{H} \psi(x) = E \psi(x),
```
and the Hamiltonian
```math
  \hat{H} = - \frac{\hbar^2}{2m} \frac{\mathrm{d}^2}{\mathrm{d}x ^2} + V(x).
```
Parameters are specified with the following struct.

#### Parameters
```@docs; canonical=false
Antique.InfinitePotentialWell
```

#### Potential
```@docs; canonical=false
Antique.V(::InfinitePotentialWell, ::Any)
```

#### Eigen Values
```@docs; canonical=false
Antique.E(::InfinitePotentialWell)
```

#### Eigen Functions
```@docs; canonical=false
Antique.ψ(::InfinitePotentialWell, ::Any)
```

#### Proofs
- [Eigen Functions & Eigen Values](https://ja.wolframalpha.com/input?i2d=true&i=D%5B%5C%2840%29Sqrt%5BDivide%5B2%2Ca%5D%5Dsin%5C%2840%29Divide%5Bn%CF%80x%2Ca%5D%5C%2841%29%5C%2841%29%2C%7Bx%2C2%7D%5D)
- [Normalization](https://ja.wolframalpha.com/input?i=Integrate%5B%28%28Sqrt%5B2%2Fa%5Dsin%28%CF%80x%2Fa%29%29%29%5E2%2C+%7Bx%2C0%2Ca%7D%5D)

## Usage & Examples

[Install Antique.jl](@ref Install) for the first use and run `using Antique` before each use. The energy `E()`, wavefunction `ψ()`, potential `V()` and some other functions are suppoted. In this system, the model is generated by `InfinitePotentialWell` and several parameters `L`, `m` and `ℏ` are set as optional arguments.

```@example IPW
using Antique
IPW = InfinitePotentialWell(L=1.0, m=1.0, ℏ=1.0)
; #hide
```

Parameters:

```@repl IPW
IPW.L
IPW.m
IPW.ℏ
```

Eigen values:

```@repl IPW
E(IPW, n=1)
E(IPW, n=2)
```

Wave functions:

```@example IPW
using Plots
plot(xlim=(0,1), xlabel="x", ylabel="ψ(x)")
plot!(x -> ψ(IPW, x, n=1), label="n=1", lw=2)
plot!(x -> ψ(IPW, x, n=2), label="n=2", lw=2)
plot!(x -> ψ(IPW, x, n=3), label="n=3", lw=2)
plot!(x -> ψ(IPW, x, n=4), label="n=4", lw=2)
plot!(x -> ψ(IPW, x, n=5), label="n=5", lw=2)
```

Potential energy curve, Energy levels, Wave functions:

```@example IPW
L = 1
using Plots
plot(xlim=(-0.5,1.5), ylim=(-5,140), xlabel="\$x\$", ylabel="\$V(x),~E_n,~\\psi_n(x)\\times5+E_n\$", size=(480,400), dpi=300)
for n in 1:5
  # energy
  plot!([0,L], fill(E(IPW,n=n),2), lc=:black, lw=2, label="")
  # wave function
  plot!(0:0.01:L, x->E(IPW,n=n) + 5*ψ(IPW,x,n=n), lc=n, lw=2, label="")
end
# potential
plot!([0,0,L,L], [140,0,0,140], lc=:black, lw=2, label="")
savefig("assets/fig/InfinitePotentialWell.png") # hide
; # hide
```

![](assets/fig/InfinitePotentialWell.png)

## Testing

Unit testing and Integration testing were done using numerical integration ([QuadGK.jl](https://juliamath.github.io/QuadGK.jl/stable/)). The test script is [here](https://github.com/ohno/Antique.jl/blob/main/test/InfinitePotentialWell.jl).

```@eval
using Markdown
using Antique
Markdown.parse(Antique.load("../../test/result/InfinitePotentialWell.log"))
```