```@meta
CurrentModule = Antique
```

# Pöschl-Teller Potential

The Pöschl-Teller potential is one of the few potentials for which the quantum mechanical Schrödinger equation has an analytical solution. It has a finite number of bound states, which can be inferred easily from its potential strength parameter λ. It is defined for one-dimensional systems.

## Definitions

This model is described with the time-independent Schrödinger equation
```math
  \hat{H} \psi(x) = E \psi(x),
```
and the Hamiltonian
```math
  \hat{H} = - \frac{\hbar^2}{2 m} \frac{\mathrm{d}^2}{\mathrm{d}x ^2} - \frac{\hbar^2}{m x_0^2} \frac{\lambda(\lambda+1)}{2}  \frac{1}{\mathrm{cosh}(x/x_0)^2}.
```

After introducing the dimensionless variables
```math
  x^\ast \equiv x/x_0,\qquad E^\ast \equiv \frac{\hbar^2}{m x_0^2} E
```
the Schrödinger equation reduces to
```math
  \hat{H}^\ast \psi(x^\ast) = E^\ast \psi(x^\ast),
```
with
```math
  \hat{H}^\ast = - \frac{1}{2} \frac{\mathrm{d}^2}{\mathrm{d}{x^\ast}^2} - \frac{\lambda(\lambda+1)}{2}  \frac{1}{\mathrm{cosh}(x^\ast)^2}.
```
Parameters are specified within the following struct.

#### Parameters
```@docs; canonical=false
Antique.PoschlTeller
```

#### Potential
```@docs; canonical=false
Antique.V(::PoschlTeller, ::Any)
```

#### Number of Bound States
```@docs; canonical=false
Antique.nₘₐₓ(::PoschlTeller)
```

#### Eigen Values
```@docs; canonical=false
Antique.E(::PoschlTeller)
```

#### Eigen Functions
```@docs; canonical=false
Antique.ψ(::PoschlTeller, ::Any)
```

#### Associated Legendre Polynomials
```@docs; canonical=false
Antique.P(::PoschlTeller, ::Any)
```

## Usage & Examples

[Install Antique.jl](@ref Install) for the first use and run `using Antique` before each use. The energy `E()`, wavefunction `ψ()`, potential `V()` and some other functions are suppoted. In this system, the model is generated by `PoschlTeller` and the parameters `λ`, `m`, `ℏ`, `x₀`.

```@example PT
using Antique
PT = PoschlTeller(λ=4.0)
; # hide
```

Parameters:

```@repl PT
PT.λ
PT.m
PT.ℏ
PT.x₀
```

Eigen values:

```@repl PT
E(PT, n=0)
E(PT, n=1)
E(PT, n=2)
E(PT, n=3)
```

Wave functions:

```@example PT
using Plots
plot(xlim=(-4,4), xlabel="\$x/x_0\$", ylabel="\$\\psi_n(x)\$")
plot!(x -> ψ(PT, x, n=0), lc=1, lw=2, label="\$n = 0\$")
plot!(x -> ψ(PT, x, n=1), lc=2, lw=2, label="\$n = 1\$")
plot!(x -> ψ(PT, x, n=2), lc=3, lw=2, label="\$n = 2\$")
plot!(x -> ψ(PT, x, n=3), lc=4, lw=2, label="\$n = 3\$")
```

Potential energy curve, Energy levels, Wave functions:

```@example PT
λ = 4.0
PT = PoschlTeller(λ=λ)

using Plots
plot(xlim=(-4,4), ylim=(-11.0,1.0), xlabel="\$x/x_0\$", ylabel="\$V(x),~E_n,~\\psi_n(x)+E_n\$", size=(480,400), dpi=300)
for n in 0:3
  # classical turning point:
  xE = acosh(sqrt(λ*(λ+1)/abs(E(PT,n=n))/2))
  # energy
  hline!([E(PT, n=n)], lc=:black, ls=:dash, label="")
  plot!([-xE,xE], fill(E(PT, n=n),2), lc=:black, lw=2, label="")
  # wave function
  plot!(x -> E(PT, n=n) + ψ(PT, x,n=n), lc=n+1, lw=2, label="\$n = $n\$")
end
# potential
plot!(x -> V(PT, x), lc=:black, lw=2, label="")
savefig("assets/fig/PoschlTeller.png") # hide
; # hide
```

![](assets/fig/PoschlTeller.png)

## Testing

Unit testing and Integration testing were done using numerical integration ([QuadGK.jl](https://juliamath.github.io/QuadGK.jl/stable/)). The test script is [here](https://github.com/ohno/Antique.jl/blob/main/test/PoschlTeller.jl).

```@eval
using Markdown
using Antique
Markdown.parse(Antique.load("../../test/result/PoschlTeller.log"))
```
